@@ -3,7 +3,7 @@ import logging
 import hashlib
 
 from ecuth.session import Session
-from ecuth.error import SessionExpiredError
+from ecuth.error import TokenExpiredError
 
 logg = logging.getLogger(__name__)
 
@@ -50,29 +50,31 @@ class Retriever:
             del self.session[identity]
 
 
-    def load(self, identity):
+
+    def load(self, k):
         """Retrieves ACL, initializes session and stores session in registry.
 
-        :param identity: Authorization digest of user
-        :type identity: bytes
+        :param k: Token or identity key
+        :type k: bytes
         :return: New session
         :rtype: ecuth.Session
         """
-        data = self.fetcher(identity)
-        logg.debug('session load {} {}'.format(identity, data))
-        acl = self.parser(data)
-        
         session = None
         try:
-            session = self.session[identity]
+            session = self.session_reverse[k]
+            logg.debug('session by auth token: {}'.format(k))
         except KeyError:
-            session = Session(identity, acl)
-            self.session[identity] = session
+            data = self.fetcher(k)
+            logg.debug('session load {} {}'.format(k, data))
+            acl = self.parser(data)
+
+            session = Session(k, acl)
+            self.session[k] = session
             self.session_reverse[session.auth] = session
             logg.debug('added session {}'.format(session))
 
         if not session.valid():
-            self.renew(identity, session.refresh)
+            raise TokenExpiredError(k)
 
         return session
 
